@@ -1,9 +1,10 @@
 """Ready to use and customizable Authentications and Oauth2 management for FastAPI"""
 
-__version__ = "0.4.0"
+__version__ = "0.6.0"
 
-from authx.api import UsersRepo as UsersRepo
+from authx.backend import UsersRepo as UsersRepo
 from authx.cache import RedisBackend as RedisBackend
+from authx.core import AuthXSocket as AuthXSocket
 from authx.core import EmailClient as EmailClient
 from authx.core import JWTBackend as JWTBackend
 from authx.core import User as User
@@ -13,6 +14,7 @@ from authx.database import MongoDBBackend as MongoDBBackend
 from authx.main import Authentication as Authentication
 from authx.main import authx as authx
 from authx.middleware import MiddlewareOauth2 as MiddlewareOauth2
+from authx.middleware import ProfilerMiddleware as ProfilerMiddleware
 from authx.middleware.service import cache as cache
 from authx.middleware.service import invalidate_cache as invalidate_cache
 from authx.models.cache import HTTPCache as HTTPCache
