@@ -4,14 +4,12 @@ from typing import Dict, Optional, Tuple
 import jwt
 from httpx import AsyncClient
 
-from authx.api import UsersRepo
+from authx.backend import UsersRepo
 from authx.core.jwt import JWTBackend
 from authx.errors import SocialException
 from authx.models.social import SocialInCreate
 from authx.models.user import UserPayload
 
-"""Social Service for authentication and authorization"""
-
 
 class SocialService:
     """Social Service is a service for social login and authorization, it is used by the API and Provide all the
