@@ -17,9 +17,9 @@ class Test(TestCase):
             "CLIENT_SECRET"
         ] = "0000000000000000000000000000000000000000000000000000000000000000"
 
-        import example.app
+        import tests.middleware.example.app as Testapp
 
-        app = example.app.app
+        app = Testapp.app
 
         cls.client = TestClient(app)
 
